@@ -16,7 +16,7 @@ tests havedist =
     (["builds"],
      [["-L", "rust"]
      ,["-l", "3"]
-     ,["-L", "-p", "rpm-ostree*.fc36"]])
+     ,["-L", "-p", "rpm-ostree*.fc37"]])
   ,
     (["tasks"],
      [["-L"]
@@ -29,18 +29,27 @@ tests havedist =
     (["find"],
      [["last", "failed", "build"]])
   ,
-        (["install", "-n", "-y"],
+    (["install", "-n", "-y"],
      [["podman", "-p", "podman"] ++ sysdist
      ,["-l", "coreutils"] ++ sysdist
-     ,["-l", "-R", "rpmlint-2.2.0-1.fc36"]
+     ,["-l", "-R", "rpmlint-2.4.0-3.fc37"]
      ,["-H", "https://kojihub.stream.centos.org/kojihub", "-d", "el9", "bash", "-p", "bash"]
      ,["-H", "stream", "-d", "el9", "kernel", "-x", "kernel-devel*", "-x", "*-debug*"]
      ,["-l", "-H", "stream", "-d", "el9", "grep"]
      ,["-H", "rpmfusion", "ffmpeg", "-p", "ffmpeg", "-p", "ffmpeg-libs"] ++ sysdist
-     ,["-l", "-H", "rpmfusion", "ffmpeg"] ++ sysdist])
+     ,["-l", "-H", "rpmfusion", "ffmpeg"] ++ sysdist
+     ,["ghc9.4",
+       "-e", "*-devel",
+       "-x", "*-prof",
+       "-x", "*-doc",
+       "-x", "ghc9.4",
+       "-x", "compiler-default",
+       "-i", "base-devel"] ++ sysdist
+     ]
+    )
   ]
   where
-    sysdist = if havedist then [] else ["-d", "fc35"]
+    sysdist = if havedist then [] else ["-d", "fc37"]
 
 main :: IO ()
 main = do
